@@ -72,17 +72,22 @@ class PowerAsset(Asset):
         return self.terminals().analogs()
 
     def time_series(
-        self, measurement_type: Union[str, List[str]] = None, timeseries_type: Union[str, List[str]] = None, **kwargs
+        self,
+        measurement_type: Union[str, List[str]] = None,
+        timeseries_type: Union[str, List[str]] = None,
+        unit: str = None,
+        **kwargs,
     ):
         """Retrieves the time series in the asset subtree.
 
         Args:
             measurement_type: Type of measurement, e.g. "ThreePhaseActivePower", or list thereof
             timeseries_type: Type of time series, e.g. "estimated_value", or list thereof
+            unit: Unit of the time series, e.g. 'kV'.
             kwargs: Other metadata filters
         """
         return PowerAssetList([self], cognite_client=self._cognite_client).time_series(
-            measurement_type=measurement_type, timeseries_type=timeseries_type, **kwargs
+            measurement_type=measurement_type, timeseries_type=timeseries_type, unit=unit, **kwargs
         )
 
     @staticmethod
@@ -231,15 +236,21 @@ class OperationalLimitType(PowerAsset):
 
 
 class ShuntCompensator(PowerAsset):
-    pass
+    def substation(self) -> "Substation":
+        """Shortcut for finding the substation for a ShuntCompensator"""
+        return assert_single_result(self.relationship_targets("Substation"))
 
 
 class StaticVarCompensator(PowerAsset):
-    pass
+    def substation(self) -> "Substation":
+        """Shortcut for finding the substation for a StaticVarCompensator"""
+        return assert_single_result(self.relationship_targets("Substation"))
 
 
 class PetersenCoil(PowerAsset):
-    pass
+    def substation(self) -> "Substation":
+        """Shortcut for finding the substation for a PetersenCoil"""
+        return assert_single_result(self.relationship_targets("Substation"))
 
 
 class PowerTransformer(PowerAsset):
@@ -728,7 +739,7 @@ class PowerAssetList(AssetList):
             raise WrongPowerTypeError(f"Can't get NonConformLoad for a list of {self.type}")
 
     def substations(self) -> "PowerAssetList":
-        """Shortcut for finding the associated Substations for a list of PowerTransformer, GeneratingUnit, (Non)ConformLoad, ACLineSegment or Terminal"""
+        """Shortcut for finding the associated Substations for a list of PowerTransformer, GeneratingUnit, (Non)ConformLoad, ACLineSegment, BusbarSection Shunt/StaticVarCompensator, PetersenCoil or Terminal"""
         if (
             self.has_type("PowerTransformer")
             or self.has_type("Terminal")
@@ -738,6 +749,9 @@ class PowerAssetList(AssetList):
             or self.has_type("ThermalGeneratingUnit")
             or self.has_type("HydroGeneratingUnit")
             or self.has_type("BusbarSection")
+            or self.has_type("ShuntCompensator")
+            or self.has_type("StaticVarCompensator")
+            or self.has_type("PetersenCoil")
         ):
             return self.relationship_targets("Substation")
         elif self.has_type("ACLineSegment"):
@@ -806,13 +820,18 @@ class PowerAssetList(AssetList):
             raise WrongPowerTypeError(f"Can't get opposite ends for a list of {self.type}")
 
     def time_series(
-        self, measurement_type: Union[str, List[str]] = None, timeseries_type: Union[str, List[str]] = None, **kwargs
+        self,
+        measurement_type: Union[str, List[str]] = None,
+        timeseries_type: Union[str, List[str]] = None,
+        unit: str = None,
+        **kwargs,
     ) -> TimeSeriesList:
         """Retrieves the time series in the asset subtrees.
 
         Args:
             measurement_type: Type of measurement, e.g. "ThreePhaseActivePower", or list thereof
             timeseries_type: Type of time series, e.g. "estimated_value", or list thereof
+            unit: Unit of the time series, e.g. 'kV'.
             kwargs: Other metadata filters"""
         if isinstance(measurement_type, str):
             measurement_type = [measurement_type]
@@ -829,6 +848,7 @@ class PowerAssetList(AssetList):
                     [
                         {
                             "asset_subtree_ids": ids[i : i + self._retrieve_chunk_size],
+                            "unit": unit,
                             "metadata": metadata_filter,
                             "limit": None,
                         }
